import logging
from logging.config import dictConfig

from pydantic import BaseSettings, validator

from settings.settings import LoggerSettings
from streamsage_python_logger.logger_configuration.formatters import formatters
from streamsage_python_logger.logger_configuration.handlers import handlers


class LoggerConfig(BaseSettings):
    context: str = ""

    def __init__(self, **kwargs):
        super().__init__(**kwargs)

    logger_config = LoggerSettings()
    LOG_LEVEL: str = logger_config.LOG_SDK_TRANSPORT_FLUENT_LEVEL

    version = 1
    disable_existing_loggers = False

    formatters = formatters
    handlers = handlers
    loggers = {
        context: {"handlers": logger_config.LOG_SDK_TRANSPORTS.split(","), "level": LOG_LEVEL},
    }

    class Config:
        validate_assignment = True

    @validator('context')
    def set_name(cls, context):
        return context


def get_logger(context):
    dictConfig(LoggerConfig(context=context).dict())
    return logging.getLogger(context)



from streamsage_python_logger.settings.settings import LoggerSettings

logger_config = LoggerSettings()

handlers = {
    "default": {
        "formatter": "default",
        "class": "logging.StreamHandler",
        "stream": "ext://sys.stderr",
        "level": logger_config.LOG_SDK_TRANSPORT_CONSOLE_LEVEL
    },
    "fluent": {
        "host": logger_config.LOG_SDK_TRANSPORT_FLUENT_URL.split(':')[0],
        "port": int(logger_config.LOG_SDK_TRANSPORT_FLUENT_URL.split(':')[1]),
        "tag": "logging",
        "buffer_overflow_handler": "overflow_handler",
        "formatter": "default",
        "timeout": logger_config.LOG_SDK_TRANSPORT_FLUENT_TIMEOUT,
        "level": logger_config.LOG_SDK_TRANSPORT_FLUENT_LEVEL,
        "class": "fluent.asynchandler.FluentHandler",
    },
}



import setuptools

setuptools.setup(name="streamsage_python_logger",
                 version="0.0.14",
                 author="streamsage",
                 description="python logger",
                 author_email="dev@streamsage.io",
                 install_requires=["fluent-logger==0.10.0",
                                   "pydantic~=1.8.0",
                                   "python-dotenv==0.19.1"],
                 packages=setuptools.find_packages(),
                 include_package_data=True,
                 license="MIT")


from pydantic import BaseModel, BaseSettings, Field


class LoggerSettings(BaseSettings):
    LOG_SDK_TRANSPORTS: str = Field("default", env="LOG_SDK_TRANSPORTS")
    LOG_SDK_TRANSPORT_FLUENT_URL: str = Field('fluent:24224', env='LOG_SDK_TRANSPORT_FLUENT_URL')
    LOG_SDK_TRANSPORT_FLUENT_LEVEL: str = Field("INFO", env="LOG_SDK_TRANSPORT_FLUENT_LEVEL=INFO")
    LOG_SDK_TRANSPORT_FLUENT_TIMEOUT: float = Field(3.0, env="LOG_SDK_TRANSPORT_FLUENT_TIMEOUT")
    LOG_SDK_TRANSPORT_CONSOLE_LEVEL: str = Field("INFO", env="LOG_SDK_TRANSPORT_CONSOLE_LEVEL")
